@@ -10,6 +10,7 @@
 #include "alarmmodel.h"
 #include "alarmplayer.h"
 #include "kclockformat.h"
+#include "savedtimezonesmodel.h"
 #include "settingsmodel.h"
 #include "stopwatchtimer.h"
 #include "timer.h"
@@ -66,20 +67,14 @@ int main(int argc, char *argv[])
     // KDBusService service(KDBusService::Unique);
 
     // initialize models
-    auto *timeZoneModel = new TimeZoneSelectorModel();
-
-    auto *timeZoneViewModel = new QSortFilterProxyModel();
-    timeZoneViewModel->setFilterFixedString("true");
-    timeZoneViewModel->setSourceModel(timeZoneModel);
-    timeZoneViewModel->setFilterRole(TimeZoneSelectorModel::ShownRole);
-
-    auto *timeZoneFilterModel = new TimeZoneFilterModel(timeZoneModel);
     auto *stopwatchTimer = new StopwatchTimer();
     auto *weekModel = new WeekModel();
 
     // register QML types
     qmlRegisterType<Alarm>("kclock", 1, 0, "Alarm");
     qmlRegisterType<Timer>("kclock", 1, 0, "Timer");
+    qmlRegisterType<SavedTimeZonesModel>("kclock", 1, 0, "SavedTimeZonesModel");
+    qmlRegisterType<TimeZoneFilterModel>("kclock", 1, 0, "TimeZoneFilterModel");
     qmlRegisterSingletonType<TimerPresetModel>("kclock", 1, 0, "TimerPresetModel", [](QQmlEngine *, QJSEngine *) -> QObject * {
         return TimerPresetModel::instance();
     });
@@ -88,9 +83,6 @@ int main(int argc, char *argv[])
 
     engine->rootContext()->setContextObject(new KLocalizedContext(engine));
     // models
-    engine->rootContext()->setContextProperty("timeZoneSelectorModel", timeZoneModel);
-    engine->rootContext()->setContextProperty("timeZoneShowModel", timeZoneViewModel);
-    engine->rootContext()->setContextProperty("timeZoneFilterModel", timeZoneFilterModel);
     engine->rootContext()->setContextProperty("alarmModel", AlarmModel::instance());
     engine->rootContext()->setContextProperty("timerModel", TimerModel::instance());
     engine->rootContext()->setContextProperty("utilModel", UtilModel::instance());
