@@ -1,6 +1,7 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
  * Copyright 2020 Devin Lin <espidev@gmail.com>
+ * Copyright 2021 Boris Petrov <boris.v.petrov@protonmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -22,10 +23,14 @@ Timer::Timer(QString uuid, bool justCreated)
         m_uuid = QUuid(m_interface->getUUID());
         m_label = m_interface->label();
         m_length = m_interface->length();
+        m_commandTimeout = m_interface->commandTimeout();
+        m_looping = m_interface->looping();
         m_running = m_interface->running();
         m_elapsed = m_interface->elapsed();
         connect(m_interface, &OrgKdeKclockTimerInterface::lengthChanged, this, &Timer::updateLength);
         connect(m_interface, &OrgKdeKclockTimerInterface::labelChanged, this, &Timer::updateLabel);
+        connect(m_interface, &OrgKdeKclockTimerInterface::commandTimeoutChanged, this, &Timer::updateCommandTimeout);
+        connect(m_interface, &OrgKdeKclockTimerInterface::loopingChanged, this, &Timer::updateLooping);
         connect(m_interface, &OrgKdeKclockTimerInterface::runningChanged, this, &Timer::updateRunning);
 
         updateRunning(); // start animation
@@ -37,6 +42,11 @@ void Timer::toggleRunning()
     m_interface->toggleRunning();
 }
 
+void Timer::toggleLooping()
+{
+    m_interface->toggleLooping();
+}
+
 void Timer::reset()
 {
     m_interface->reset();
@@ -75,6 +85,18 @@ void Timer::updateRunning()
     Q_EMIT elapsedChanged();
 }
 
+void Timer::updateLooping()
+{
+    m_looping = m_interface->looping();
+    Q_EMIT propertyChanged();
+}
+
+void Timer::updateCommandTimeout()
+{
+    m_commandTimeout = m_interface->commandTimeout();
+    Q_EMIT propertyChanged();
+}
+
 void Timer::animation(bool start)
 {
     if (!m_timer) {
