@@ -26,8 +26,6 @@ public:
         ShownRole = Qt::UserRole + 0,
         OffsetRole = Qt::UserRole + 1,
         ShortNameRole = Qt::UserRole + 2,
-        TimeStringRole,
-        RelativeTimeRole,
         IDRole
     };
 
@@ -37,9 +35,6 @@ public:
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QHash<int, QByteArray> roleNames() const override;
 
-public Q_SLOTS:
-    Q_INVOKABLE void update();
-
 private:
     QList<std::tuple<QTimeZone, bool>> m_list;
 };
@@ -49,15 +44,7 @@ class TimeZoneFilterModel : public QSortFilterProxyModel
     Q_OBJECT
 
 public:
-    explicit TimeZoneFilterModel(TimeZoneSelectorModel *model, QObject *parent = nullptr);
-};
-
-class TimeZoneViewModel : public QSortFilterProxyModel
-{
-    Q_OBJECT
-
-public:
-    explicit TimeZoneViewModel(TimeZoneSelectorModel *model, QObject *parent = nullptr);
+    explicit TimeZoneFilterModel(QObject *parent = nullptr);
 };
 
 #endif // KCLOCK_TIMEZONESELECTORMODEL_H
