@@ -1,11 +1,14 @@
 /*
  * Copyright 2020 Han Young <hanyoung@protonmail.com>
+ * Copyright 2021 Boris Petrov <boris.v.petrov@protonmail.com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "timer.h"
 
+#include <QProcess>
+
 #include "utilities.h"
 
 #include <KLocalizedString>
@@ -16,10 +19,11 @@
 
 /* ~ Timer ~ */
 
-Timer::Timer(int length, QString label, bool running)
+Timer::Timer(int length, QString label, QString commandTimeout, bool running)
     : m_uuid(QUuid::createUuid())
     , m_length(length)
     , m_label(label)
+    , m_commandTimeout(commandTimeout)
 {
     connect(&Utilities::instance(), &Utilities::wakeup, this, &Timer::timeUp);
     connect(&Utilities::instance(), &Utilities::needsReschedule, this, &Timer::reschedule);
@@ -38,6 +42,8 @@ Timer::Timer(const QJsonObject &obj)
     m_length = obj[QStringLiteral("length")].toInt();
     m_label = obj[QStringLiteral("label")].toString();
     m_uuid = QUuid(obj[QStringLiteral("uuid")].toString());
+    m_looping = obj[QStringLiteral("looping")].toBool();
+    m_commandTimeout = obj[QStringLiteral("commandTimeout")].toString();
 
     connect(&Utilities::instance(), &Utilities::wakeup, this, &Timer::timeUp);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Timers/") + this->m_uuid.toString(QUuid::Id128),
@@ -61,6 +67,8 @@ QJsonObject Timer::serialize()
     obj[QStringLiteral("length")] = m_length;
     obj[QStringLiteral("label")] = m_label;
     obj[QStringLiteral("uuid")] = m_uuid.toString();
+    obj[QStringLiteral("looping")] = m_looping;
+    obj[QStringLiteral("commandTimeout")] = m_commandTimeout;
     return obj;
 }
 
@@ -69,6 +77,15 @@ void Timer::toggleRunning()
     setRunning(!m_running);
 }
 
+void Timer::toggleLooping()
+{
+    m_looping = !m_looping;
+
+    Q_EMIT loopingChanged();
+
+    TimerModel::instance()->save();
+}
+
 void Timer::reset()
 {
     setRunning(false);
@@ -82,8 +99,17 @@ void Timer::timeUp(int cookie)
     if (cookie == m_cookie) {
         this->sendNotification();
         this->m_cookie = -1;
-        this->setRunning(false);
-        this->m_hasElapsed = m_length;
+        if (m_commandTimeout != "") {
+            QProcess *process = new QProcess;
+            process->start(m_commandTimeout);
+        }
+        if (m_looping) {
+            this->reset();
+            this->setRunning(true);
+        } else {
+            this->setRunning(false);
+            this->m_hasElapsed = m_length;
+        }
     }
 }
 
