@@ -7,12 +7,13 @@
 #include "utilities.h"
 
 #include <QDBusReply>
+#include <QDBusServiceWatcher>
 #include <QDebug>
 #include <QThread>
 
 Utilities::Utilities(QObject *parent)
     : QObject(parent)
-    , m_interface(new QDBusInterface(QStringLiteral("org.kde.Solid.PowerManagement"),
+    , m_interface(new QDBusInterface(POWERDEVIL_SERVICE_NAME,
                                      QStringLiteral("/org/kde/Solid/PowerManagement"),
                                      QStringLiteral("org.kde.Solid.PowerManagement"),
                                      QDBusConnection::sessionBus(),
@@ -21,36 +22,39 @@ Utilities::Utilities(QObject *parent)
     // if PowerDevil is present, we can rely on PowerDevil to track time, otherwise we do it ourself
     if (m_interface->isValid()) {
         // test Plasma 5.20 PowerDevil schedule wakeup feature
-        QDBusMessage m = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
-                                                        QStringLiteral("/org/kde/Solid/PowerManagement"),
-                                                        QStringLiteral("org.freedesktop.DBus.Introspectable"),
-                                                        QStringLiteral("Introspect"));
-        QDBusReply<QString> result = QDBusConnection::sessionBus().call(m);
-
-        if (result.isValid() && result.value().indexOf(QStringLiteral("scheduleWakeup")) >= 0) { // have this feature
-            m_hasPowerDevil = true;
-        }
+        m_hasPowerDevil = hasWakeup();
     }
 
+    bool success = QDBusConnection::sessionBus().registerObject(QStringLiteral("/Utility"),
+                                                                QStringLiteral("org.kde.PowerManagement"),
+                                                                this,
+                                                                QDBusConnection::ExportScriptableSlots);
+    qDebug() << "Register Utility on DBus: " << success;
     if (this->hasPowerDevil()) {
-        bool success = QDBusConnection::sessionBus().registerObject(QStringLiteral("/Utility"),
-                                                                    QStringLiteral("org.kde.PowerManagement"),
-                                                                    this,
-                                                                    QDBusConnection::ExportScriptableSlots);
-        qDebug() << "PowerDevil found, using it for time tracking. Success:" << success;
+        qDebug() << "PowerDevil found, using it for time tracking.";
     } else {
-        m_timerThread = new QThread(this);
-        m_worker = new AlarmWaitWorker();
-        m_worker->moveToThread(m_timerThread);
-        connect(m_worker, &AlarmWaitWorker::finished, [this] {
-            // notify time is up
-            Q_EMIT this->wakeup(m_currentCookie);
-            this->clearWakeup(m_currentCookie);
-        });
-        m_timerThread->start();
+        initWorker();
 
         qDebug() << "PowerDevil not found, using wait worker thread for time tracking.";
     }
+
+    auto m_watcher = new QDBusServiceWatcher{POWERDEVIL_SERVICE_NAME,
+                                             QDBusConnection::sessionBus(),
+                                             QDBusServiceWatcher::WatchForRegistration | QDBusServiceWatcher::WatchForUnregistration};
+    connect(m_watcher, &QDBusServiceWatcher::serviceRegistered, [this]() {
+        qDebug() << "powerdevil found";
+        m_hasPowerDevil = hasWakeup();
+        if (m_hasPowerDevil && m_timerThread)
+            m_timerThread->quit();
+
+        Q_EMIT needsReschedule();
+    });
+    connect(m_watcher, &QDBusServiceWatcher::serviceUnregistered, [this]() {
+        m_hasPowerDevil = false;
+        initWorker();
+
+        Q_EMIT needsReschedule();
+    });
 }
 
 int Utilities::scheduleWakeup(quint64 timestamp)
@@ -116,3 +120,31 @@ void Utilities::schedule()
     }
     m_worker->setNewTime(minTime); // Unix uses int64 internally for time, if we don't have anything to wait, we wait to year 2262 A.D.
 }
+void Utilities::initWorker()
+{
+    if (!m_timerThread) {
+        m_timerThread = new QThread(this);
+        m_worker = new AlarmWaitWorker();
+        m_worker->moveToThread(m_timerThread);
+        connect(m_worker, &AlarmWaitWorker::finished, [this] {
+            // notify time is up
+            Q_EMIT this->wakeup(m_currentCookie);
+            this->clearWakeup(m_currentCookie);
+        });
+    }
+    m_timerThread->start();
+}
+bool Utilities::hasWakeup()
+{
+    QDBusMessage m = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
+                                                    QStringLiteral("/org/kde/Solid/PowerManagement"),
+                                                    QStringLiteral("org.freedesktop.DBus.Introspectable"),
+                                                    QStringLiteral("Introspect"));
+    QDBusReply<QString> result = QDBusConnection::sessionBus().call(m);
+
+    if (result.isValid() && result.value().indexOf(QStringLiteral("scheduleWakeup")) >= 0) { // have this feature
+        return true;
+    } else {
+        return false;
+    }
+}
